@@ -12,8 +12,20 @@ namespace treelite {
 namespace compiler {
 namespace native {
 
-const char* header_template =
+const char* const query_functions_prototype_template =
 R"TREELITETEMPLATE(
+{dllexport}size_t get_num_class(void);
+{dllexport}size_t get_num_feature(void);
+{dllexport}const char* get_pred_transform(void);
+{dllexport}float get_sigmoid_alpha(void);
+{dllexport}float get_global_bias(void);
+{dllexport}const char* get_threshold_type(void);
+{dllexport}const char* get_leaf_output_type(void);
+)TREELITETEMPLATE";
+
+const char* const header_template =
+R"TREELITETEMPLATE(
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
@@ -29,25 +41,21 @@ R"TREELITETEMPLATE(
 
 union Entry {{
   int missing;
-  float fvalue;
+  {threshold_type} fvalue;
   int qvalue;
 }};
 
 struct Node {{
   uint8_t default_left;
   unsigned int split_index;
-  {threshold_type} threshold;
+  {threshold_type_Node} threshold;
   int left_child;
   int right_child;
 }};
 
 extern const unsigned char is_categorical[];
 
-{dllexport}{get_num_output_group_function_signature};
-{dllexport}{get_num_feature_function_signature};
-{dllexport}{get_pred_transform_function_signature};
-{dllexport}{get_sigmoid_alpha_function_signature};
-{dllexport}{get_global_bias_function_signature};
+{query_functions_prototype}
 {dllexport}{predict_function_signature};
 )TREELITETEMPLATE";
 
